ErrorPosition

Struct ErrorPosition 

pub struct ErrorPosition {
    pub start: (usize, usize),
    pub end: Option<(usize, usize)>,
}
A struct to store the position of an error

Fields

start: (usize, usize)

The start position of the error. The first value is the line, the second is the column

end: Option<(usize, usize)>

The end position of the error. The first value is the line, the second is the column.

Implementations

Source

impl ErrorPosition

pub fn new(start: (usize, usize), end: Option<(usize, usize)>) -> Self